"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = collector;
var _logger = require("@linaria/logger");
var _utils = require("@linaria/utils");
var _processTemplateExpression = require("../utils/processTemplateExpression");
/**
 * Collector traverses the AST and collects information about imports and
 * all Linaria template literals.
 */

function collector(babel, options) {
  var _options$values;
  const values = (_options$values = options.values) !== null && _options$values !== void 0 ? _options$values : new Map();
  return {
    name: '@linaria/babel/collector',
    pre(file) {
      var _file$path$scope$getD;
      (0, _logger.debug)('collect:start', file.opts.filename);
      const processors = [];
      const identifiers = [];
      file.path.traverse({
        Identifier: p => {
          identifiers.push(p);
        }
      });

      // TODO: process transformed literals
      identifiers.forEach(p => {
        (0, _processTemplateExpression.processTemplateExpression)(p, file.opts, options, processor => {
          processor.build(values);
          processor.doRuntimeReplacement();
          processors.push(processor);
        });
      });
      if (processors.length === 0) {
        // We didn't find any Linaria template literals.
        return;
      }
      this.file.metadata.linaria = {
        processors,
        replacements: [],
        rules: {},
        dependencies: []
      };

      // We can remove __linariaPreval export and all related code
      const prevalExport = (_file$path$scope$getD = file.path.scope.getData('__linariaPreval')) === null || _file$path$scope$getD === void 0 ? void 0 : _file$path$scope$getD.findParent(p => p.isExpressionStatement());
      if (prevalExport) {
        (0, _utils.removeWithRelated)([prevalExport]);
      }
      (0, _logger.debug)('collect:end', file.opts.filename);
    },
    visitor: {}
  };
}
//# sourceMappingURL=collector.js.map